package com.tarfeef101.pwm

import android.annotation.SuppressLint
import android.content.Context
import android.content.res.Configuration
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.widget.RadioButton
import android.widget.RadioGroup
import android.widget.TextClock
import android.widget.TextView
import androidx.appcompat.app.AppCompatDelegate
import kotlinx.android.synthetic.main.activity_home.*
import kotlinx.android.synthetic.main.activity_theme.*

@SuppressLint("SetTextI18n")
class ThemeActivity : AppCompatActivity()
{
  override fun onCreate(savedInstanceState: Bundle?)
  {
    super.onCreate(savedInstanceState)
    setContentView(R.layout.activity_theme)

    // actionbar bootstrap
    setSupportActionBar(toolbar2)
    toolbar2.showOverflowMenu()
    getSupportActionBar()?.setDisplayHomeAsUpEnabled(true)

    // load shared preferences file
    val pref = this.getSharedPreferences("prefs", Context.MODE_PRIVATE)
    // retrieve user dark mode setting
    val last_dark_setting = pref.getInt("dark", -1)
    // set radio button based on this
    if (last_dark_setting == -1)
    {
      // no preference, use default
      themeRadioGroup.check(radioButtonDefault.id)
    } else if (last_dark_setting == 0)
    {
      // user wants light mode, loser that they are
      themeRadioGroup.check(radioButtonLight.id)
    } else
    {
      // we have a dark moder!
      themeRadioGroup.check(radioButtonDark.id)
    }

    // define objects, set text values for em
    radioButtonDefault.setText("System Default")
    radioButtonDark.setText("Dark")
    radioButtonLight.setText("Light")

    // set system theme based on active user choice
    fun setTheme()
    {
      val active = findViewById<RadioButton>(themeRadioGroup.checkedRadioButtonId)
      when (active)
      {
          radioButtonDefault ->
          {
              with(pref.edit())
              {
                  putInt("dark", -1)
                  apply()
              }
              ThemeHelper.apply(-1)
          }
          radioButtonDark ->
          {
              with(pref.edit())
              {
                  putInt("dark", 1)
                  apply()
              }
              ThemeHelper.apply(1)
          }
          radioButtonLight ->
          {
              with(pref.edit())
              {
                  putInt("dark", 0)
                  apply()
              }
              ThemeHelper.apply(0)
          }
      }
      themeStatus.setText(active.getText())
    }

    // set the listener for changes to the radio button group
    setTheme()
    themeRadioGroup.setOnCheckedChangeListener { _, _ -> setTheme() }
  }
}